import React, { useState, useEffect } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { useLocation } from 'react-router-dom';
import { showNotification } from '../../../store/notification.slice';
import {
    fetchPermissionsThunk,
    approvePermissionThunk,
    rejectPermissionThunk,
} from '../../../store/permissions/permissions.thunks';
import { resetOperationStatus } from '../../../store/permissions/permissions.slice';
import './PendingRequests.css'; // 引入外部CSS文件
import SvgIcon from '../../../components/SvgIcon';
import RequestDetailSlideOver from './RequestDetailSlideOver';

// 每页显示的申请数量
const PAGE_SIZE = 5;

export default function PendingRequests() {
    const dispatch = useDispatch();
    const location = useLocation();
    const [responseMessage, setResponseMessage] = useState('');
    const [showResponseInput, setShowResponseInput] = useState(false);
    const [currentRequestId, setCurrentRequestId] = useState(null);
    const [isApproving, setIsApproving] = useState(false);
    const [selectedRequest, setSelectedRequest] = useState(null);
    const [showSlideOver, setShowSlideOver] = useState(false);

    // 使用本地状态管理待处理申请列表
    const [pendingRequests, setPendingRequests] = useState([]);
    const [fetchStatus, setFetchStatus] = useState('idle');
    const [fetchError, setFetchError] = useState(null);

    // 分页状态
    const [currentPage, setCurrentPage] = useState(1);
    const [totalPages, setTotalPages] = useState(1);

    // 从Redux store获取批准/拒绝操作的状态
    const {
        status: approveRejectStatus,
        error: approveRejectError,
        currentId: processingId,
    } = useSelector((state) => state.permissions.approveReject);

    // 获取待处理申请列表
    useEffect(() => {
        const fetchData = async () => {
            try {
                setFetchStatus('loading');
                const result = await dispatch(fetchPermissionsThunk());
                if (result.payload) {
                    setPendingRequests(result.payload);
                    setTotalPages(Math.ceil(result.payload.length / PAGE_SIZE));
                }
                setFetchStatus('succeeded');
            } catch (error) {
                console.error('获取待处理申请列表失败:', error);
                setFetchError(error.message || '获取待处理申请列表失败');
                setFetchStatus('failed');
            }
        };

        fetchData();
    }, [dispatch]);

    // 处理从通知中心跳转过来的请求
    useEffect(() => {
        if (location.state?.showRequestDetail) {
            const { requestId, requestData } = location.state;
            setSelectedRequest(requestData);
            setShowSlideOver(true);
            // 清除 location state
            window.history.replaceState({}, document.title);
        }
    }, [location.state]);

    // 监听批准/拒绝操作的状态变化
    useEffect(() => {
        if (approveRejectStatus === 'succeeded') {
            dispatch(
                showNotification({
                    message: isApproving ? '已批准申请' : '已拒绝申请',
                    type: 'success',
                })
            );
            setShowResponseInput(false);
            setCurrentRequestId(null);
            setResponseMessage('');
            setShowSlideOver(false);
            setSelectedRequest(null);

            // 从列表中移除已处理的申请
            const updatedRequests = pendingRequests.filter((req) => req.id !== currentRequestId);
            setPendingRequests(updatedRequests);

            // 更新总页数
            setTotalPages(Math.ceil(updatedRequests.length / PAGE_SIZE));

            // 如果当前页没有数据了，且不是第一页，则回到上一页
            if (getCurrentPageData().length === 1 && currentPage > 1) {
                setCurrentPage(currentPage - 1);
            }

            // 重置状态
            dispatch(resetOperationStatus());
        } else if (approveRejectStatus === 'failed') {
            dispatch(
                showNotification({
                    message: approveRejectError || '处理申请失败',
                    type: 'danger',
                })
            );
            // 重置状态
            dispatch(resetOperationStatus());
        }
    }, [
        approveRejectStatus,
        approveRejectError,
        dispatch,
        isApproving,
        currentRequestId,
        pendingRequests,
        currentPage,
    ]);

    // 打开回复输入框
    const handleOpenResponseInput = (requestId, approving) => {
        setCurrentRequestId(requestId);
        setIsApproving(approving);
        setShowResponseInput(true);
    };

    // 关闭回复输入框
    const handleCloseResponseInput = () => {
        setShowResponseInput(false);
        setCurrentRequestId(null);
        setResponseMessage('');
    };

    // 处理申请（批准或拒绝）
    const handleProcessRequest = () => {
        if (!currentRequestId) return;

        const params = {
            id: currentRequestId,
            responseMessage,
        };

        if (isApproving) {
            dispatch(approvePermissionThunk(params));
        } else {
            dispatch(rejectPermissionThunk(params));
        }
    };

    // 处理行点击，显示滑动面板
    const handleRowClick = (request) => {
        setSelectedRequest(request);
        setShowSlideOver(true);
    };

    // 关闭滑动面板
    const handleCloseSlideOver = () => {
        setShowSlideOver(false);
        setTimeout(() => {
            setSelectedRequest(null);
        }, 300); // 等待动画结束后再清除选中的申请
    };

    // 直接处理申请（不显示弹窗）
    const handleDirectProcess = (requestId, approve) => {
        setCurrentRequestId(requestId);
        setIsApproving(approve);

        const params = {
            id: requestId,
            responseMessage: approve ? '已批准' : '已拒绝',
        };

        if (approve) {
            dispatch(approvePermissionThunk(params));
        } else {
            dispatch(rejectPermissionThunk(params));
        }
    };

    // 获取当前页的数据
    const getCurrentPageData = () => {
        const startIndex = (currentPage - 1) * PAGE_SIZE;
        const endIndex = startIndex + PAGE_SIZE;
        return Array.isArray(pendingRequests) ? pendingRequests.slice(startIndex, endIndex) : [];
    };

    // 处理页码变化
    const handlePageChange = (page) => {
        setCurrentPage(page);
    };

    // 渲染分页控件
    const renderPagination = () => {
        if (totalPages <= 1) return null;

        return (
            <div className='pagination-container'>
                <button
                    className='pagination-button'
                    onClick={() => handlePageChange(currentPage - 1)}
                    disabled={currentPage === 1}
                >
                    上一页
                </button>

                <div className='pagination-info'>
                    {currentPage} / {totalPages}
                </div>

                <button
                    className='pagination-button'
                    onClick={() => handlePageChange(currentPage + 1)}
                    disabled={currentPage === totalPages}
                >
                    下一页
                </button>
            </div>
        );
    };

    // 渲染加载状态
    if (fetchStatus === 'loading' && pendingRequests.length === 0) {
        return (
            <div className='text-center py-5'>
                <div className='spinner-border' role='status'>
                    <span className='visually-hidden'>加载中...</span>
                </div>
                <p className='mt-3'>加载待处理申请...</p>
            </div>
        );
    }

    // 渲染错误状态
    if (fetchStatus === 'failed' && pendingRequests.length === 0) {
        return (
            <div className='alert alert-danger' role='alert'>
                {fetchError || '获取待处理申请失败'}
            </div>
        );
    }

    // 渲染空状态
    if (pendingRequests.length === 0) {
        return (
            <div className='alert alert-info' role='alert'>
                暂无待处理的权限申请
            </div>
        );
    }

    // 获取当前页的数据
    const currentPageData = getCurrentPageData();

    // 渲染申请列表
    return (
        <>
            <div className='d-flex justify-content-between align-items-center mb-3'>
                <h5 className='mb-0'>待处理申请</h5>
                <div className='badge bg-danger'>{pendingRequests.length}个待处理</div>
            </div>

            <div className='pending-requests-list'>
                {currentPageData.map((request) => (
                    <div key={request.id} className='pending-request-item' onClick={() => handleRowClick(request)}>
                        <div className='request-header'>
                            <div className='user-info'>
                                <h6 className='mb-0'>{request.applicant}</h6>
                            </div>
                            <div className='request-date'>{new Date(request.created_at).toLocaleDateString()}</div>
                        </div>

                        <div className='request-content'>
                            <p className='mb-2'>申请访问：{request.knowledge_base}</p>

                            {request.permissions.can_edit ? (
                                <span
                                    className='badge bg-success-subtle text-success d-flex align-items-center gap-1'
                                    style={{ width: 'fit-content' }}
                                >
                                    <SvgIcon className={'circle-yes'} />
                                    完全访问
                                </span>
                            ) : (
                                request.permissions.can_read && (
                                    <span
                                        className='badge bg-warning-subtle text-warning d-flex align-items-center gap-1'
                                        style={{ width: 'fit-content' }}
                                    >
                                        <SvgIcon className={'eye'} />
                                        只读访问
                                    </span>
                                )
                            )}
                        </div>
                        <div className='request-actions'>
                            <button
                                className='btn btn-outline-danger btn-sm'
                                onClick={(e) => {
                                    e.stopPropagation();
                                    handleDirectProcess(request.id, false);
                                }}
                                disabled={processingId === request.id && approveRejectStatus === 'loading'}
                            >
                                {processingId === request.id && approveRejectStatus === 'loading' && !isApproving
                                    ? '处理中...'
                                    : '拒绝'}
                            </button>
                            <button
                                className='btn btn-outline-success btn-sm'
                                onClick={(e) => {
                                    e.stopPropagation();
                                    handleDirectProcess(request.id, true);
                                }}
                                disabled={processingId === request.id && approveRejectStatus === 'loading'}
                            >
                                {processingId === request.id && approveRejectStatus === 'loading' && isApproving
                                    ? '处理中...'
                                    : '批准'}
                            </button>
                        </div>
                    </div>
                ))}
            </div>

            {/* 分页控件 */}
            {renderPagination()}

            {/* 使用新的滑动面板组件 */}
            <RequestDetailSlideOver
                show={showSlideOver}
                onClose={handleCloseSlideOver}
                request={selectedRequest}
                onApprove={(id) => handleOpenResponseInput(id, true)}
                onReject={(id) => handleOpenResponseInput(id, false)}
                processingId={processingId}
                approveRejectStatus={approveRejectStatus}
                isApproving={isApproving}
            />

            {/* 回复输入弹窗 */}
            {showResponseInput && (
                <div className='modal fade show' style={{ display: 'block' }} tabIndex='-1'>
                    <div className='modal-dialog'>
                        <div className='modal-content'>
                            <div className='modal-header'>
                                <h5 className='modal-title'>{isApproving ? '批准' : '拒绝'}申请</h5>
                                <button
                                    type='button'
                                    className='btn-close'
                                    onClick={handleCloseResponseInput}
                                    disabled={approveRejectStatus === 'loading'}
                                ></button>
                            </div>
                            <div className='modal-body'>
                                <div className='mb-3'>
                                    <label htmlFor='responseMessage' className='form-label'>
                                        审批意见
                                    </label>
                                    <textarea
                                        className='form-control'
                                        id='responseMessage'
                                        rows='3'
                                        value={responseMessage}
                                        onChange={(e) => setResponseMessage(e.target.value)}
                                        placeholder={isApproving ? '请输入批准意见（可选）' : '请输入拒绝理由（可选）'}
                                    ></textarea>
                                </div>
                            </div>
                            <div className='modal-footer'>
                                <button
                                    type='button'
                                    className='btn btn-secondary'
                                    onClick={handleCloseResponseInput}
                                    disabled={approveRejectStatus === 'loading'}
                                >
                                    取消
                                </button>
                                <button
                                    type='button'
                                    className={`btn ${isApproving ? 'btn-success' : 'btn-danger'}`}
                                    onClick={handleProcessRequest}
                                    disabled={approveRejectStatus === 'loading'}
                                >
                                    {approveRejectStatus === 'loading' ? (
                                        <>
                                            <span
                                                className='spinner-border spinner-border-sm me-1'
                                                role='status'
                                                aria-hidden='true'
                                            ></span>
                                            处理中...
                                        </>
                                    ) : isApproving ? (
                                        '确认批准'
                                    ) : (
                                        '确认拒绝'
                                    )}
                                </button>
                            </div>
                        </div>
                    </div>
                    <div className='modal-backdrop fade show'></div>
                </div>
            )}
        </>
    );
}
