import React, { useState, useEffect } from 'react';
import { get } from '../../../services/api';

// 模拟用户权限数据
const mockUserPermissions = [
    {
        knowledge_base: {
            id: '1',
            name: '达人直播数据报告',
            department: '达人组',
        },
        permission: {
            can_read: true,
            can_edit: true,
            can_admin: false,
        },
        last_access_time: '2024-03-10T14:30:00Z',
    },
    {
        knowledge_base: {
            id: '2',
            name: '人力资源政策文件',
            department: '人力资源组',
        },
        permission: {
            can_read: true,
            can_edit: false,
            can_admin: false,
        },
        last_access_time: '2024-03-08T09:15:00Z',
    },
    {
        knowledge_base: {
            id: '3',
            name: '市场分析报告',
            department: '市场部',
        },
        permission: {
            can_read: true,
            can_edit: false,
            can_admin: false,
        },
        last_access_time: null,
    },
    {
        knowledge_base: {
            id: '4',
            name: '产品规划文档',
            department: '产品部',
        },
        permission: {
            can_read: true,
            can_edit: true,
            can_admin: true,
        },
        last_access_time: '2024-03-15T11:20:00Z',
    },
];

export default function UserPermissionDetails({ user, onClose, onSave }) {
    const [userPermissions, setUserPermissions] = useState([]);
    const [loading, setLoading] = useState(true);
    const [error, setError] = useState(null);
    const [updatedPermissions, setUpdatedPermissions] = useState({});

    // 获取用户权限详情
    useEffect(() => {
        const fetchUserPermissions = async () => {
            try {
                setLoading(true);
                const response = await get(`/users/${user.user.id}/permissions/`);

                if (response && response.code === 200) {
                    // 检查API返回的数据
                    const apiPermissions = response.data.permissions || [];
                    if (apiPermissions.length > 0) {
                        // 使用API返回的数据
                        setUserPermissions(apiPermissions);
                        console.log('使用API返回的用户权限数据');
                    } else {
                        // API返回的数据为空，使用模拟数据
                        console.log('API返回的用户权限数据为空，使用模拟数据');
                        setUserPermissions(mockUserPermissions);
                    }
                } else {
                    // API请求失败，使用模拟数据
                    console.log('API请求失败，使用模拟数据');
                    setUserPermissions(mockUserPermissions);
                    setError('获取用户权限详情失败，显示模拟数据');
                }
            } catch (error) {
                console.error('获取用户权限详情失败:', error);
                // API请求出错，使用模拟数据作为后备
                console.log('API请求出错，使用模拟数据作为后备');
                setUserPermissions(mockUserPermissions);
                setError('获取用户权限详情失败，显示模拟数据');
            } finally {
                setLoading(false);
            }
        };

        if (user) {
            fetchUserPermissions();
        }
    }, [user]);

    // 处理权限变更
    const handlePermissionChange = (knowledgeBaseId, permissionType) => {
        setUpdatedPermissions({
            ...updatedPermissions,
            [knowledgeBaseId]: permissionType,
        });
    };

    // 处理保存
    const handleSave = () => {
        onSave(user.user.id, updatedPermissions);
    };

    // 获取权限类型的显示文本
    const getPermissionTypeText = (permissionType) => {
        switch (permissionType) {
            case 'none':
                return '无权限';
            case 'read':
                return '只读访问';
            case 'edit':
                return '编辑权限';
            case 'admin':
                return '管理权限';
            default:
                return '未知权限';
        }
    };

    // 获取权限类型的值
    const getPermissionType = (permission) => {
        if (!permission) return 'none';
        if (permission.can_admin) return 'admin';
        if (permission.can_edit) return 'edit';
        if (permission.can_read) return 'read';
        return 'none';
    };

    return (
        <div className='modal fade show' style={{ display: 'block' }} tabIndex='-1'>
            <div className='modal-dialog modal-lg modal-dialog-scrollable' style={{ zIndex: 9999 }}>
                <div className='modal-content'>
                    <div className='modal-header'>
                        <h5 className='modal-title'>{user.user.name} 的权限详情</h5>
                        <button type='button' className='btn-close' onClick={onClose}></button>
                    </div>
                    <div className='modal-body'>
                        {loading ? (
                            <div className='text-center py-4'>
                                <div className='spinner-border' role='status'>
                                    <span className='visually-hidden'>加载中...</span>
                                </div>
                                <p className='mt-3'>加载权限详情...</p>
                            </div>
                        ) : error ? (
                            <div>
                                <div className='alert alert-warning' role='alert'>
                                    {error}
                                </div>
                                {userPermissions.length > 0 && (
                                    <div className='table-responsive'>
                                        <table className='table table-hover'>
                                            <thead className='table-light'>
                                                <tr>
                                                    <th>知识库名称</th>
                                                    <th>所属部门</th>
                                                    <th>当前权限</th>
                                                    <th>最后访问时间</th>
                                                    <th>操作</th>
                                                </tr>
                                            </thead>
                                            <tbody>
                                                {userPermissions.map((item) => {
                                                    const currentPermissionType = getPermissionType(item.permission);
                                                    const updatedPermissionType =
                                                        updatedPermissions[item.knowledge_base.id] ||
                                                        currentPermissionType;

                                                    return (
                                                        <tr key={item.knowledge_base.id}>
                                                            <td>{item.knowledge_base.name}</td>
                                                            <td>{item.knowledge_base.department || '未指定'}</td>
                                                            <td>
                                                                <span
                                                                    className={`badge ${
                                                                        currentPermissionType === 'admin'
                                                                            ? 'bg-danger'
                                                                            : currentPermissionType === 'edit'
                                                                            ? 'bg-success'
                                                                            : currentPermissionType === 'read'
                                                                            ? 'bg-info'
                                                                            : 'bg-secondary'
                                                                    }`}
                                                                >
                                                                    {getPermissionTypeText(currentPermissionType)}
                                                                </span>
                                                            </td>
                                                            <td>
                                                                {item.last_access_time
                                                                    ? new Date(item.last_access_time).toLocaleString()
                                                                    : '从未访问'}
                                                            </td>
                                                            <td>
                                                                <select
                                                                    className='form-select form-select-sm'
                                                                    value={updatedPermissionType}
                                                                    onChange={(e) =>
                                                                        handlePermissionChange(
                                                                            item.knowledge_base.id,
                                                                            e.target.value
                                                                        )
                                                                    }
                                                                >
                                                                    <option value='none'>无权限</option>
                                                                    <option value='read'>只读访问</option>
                                                                    <option value='edit'>编辑权限</option>
                                                                    <option value='admin'>管理权限</option>
                                                                </select>
                                                            </td>
                                                        </tr>
                                                    );
                                                })}
                                            </tbody>
                                        </table>
                                    </div>
                                )}
                            </div>
                        ) : userPermissions.length === 0 ? (
                            <div className='alert alert-info' role='alert'>
                                该用户暂无任何知识库权限
                            </div>
                        ) : (
                            <div className='table-responsive'>
                                <table className='table table-hover'>
                                    <thead className='table-light'>
                                        <tr>
                                            <th>知识库名称</th>
                                            <th>所属部门</th>
                                            <th>当前权限</th>
                                            <th>最后访问时间</th>
                                            <th>操作</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        {userPermissions.map((item) => {
                                            const currentPermissionType = getPermissionType(item.permission);
                                            const updatedPermissionType =
                                                updatedPermissions[item.knowledge_base.id] || currentPermissionType;

                                            return (
                                                <tr key={item.knowledge_base.id}>
                                                    <td>{item.knowledge_base.name}</td>
                                                    <td>{item.knowledge_base.department || '未指定'}</td>
                                                    <td>
                                                        <span
                                                            className={`badge ${
                                                                currentPermissionType === 'admin'
                                                                    ? 'bg-danger'
                                                                    : currentPermissionType === 'edit'
                                                                    ? 'bg-success'
                                                                    : currentPermissionType === 'read'
                                                                    ? 'bg-info'
                                                                    : 'bg-secondary'
                                                            }`}
                                                        >
                                                            {getPermissionTypeText(currentPermissionType)}
                                                        </span>
                                                    </td>
                                                    <td>
                                                        {item.last_access_time
                                                            ? new Date(item.last_access_time).toLocaleString()
                                                            : '从未访问'}
                                                    </td>
                                                    <td>
                                                        <select
                                                            className='form-select form-select-sm'
                                                            value={updatedPermissionType}
                                                            onChange={(e) =>
                                                                handlePermissionChange(
                                                                    item.knowledge_base.id,
                                                                    e.target.value
                                                                )
                                                            }
                                                        >
                                                            <option value='none'>无权限</option>
                                                            <option value='read'>只读访问</option>
                                                            <option value='edit'>编辑权限</option>
                                                            <option value='admin'>管理权限</option>
                                                        </select>
                                                    </td>
                                                </tr>
                                            );
                                        })}
                                    </tbody>
                                </table>
                            </div>
                        )}
                    </div>
                    <div className='modal-footer'>
                        <button type='button' className='btn btn-secondary' onClick={onClose}>
                            关闭
                        </button>
                        <button
                            type='button'
                            className='btn btn-dark'
                            onClick={handleSave}
                            disabled={loading || Object.keys(updatedPermissions).length === 0}
                        >
                            保存更改
                        </button>
                    </div>
                </div>
            </div>
            <div className='modal-backdrop fade show' style={{ zIndex: 1050 }}></div>
        </div>
    );
}
